var canvas = document.getElementById("playArea");
var ctx = canvas.getContext("2d");
var bar = document.getElementById("dvGameBar");
var score = document.getElementById("lblScore");
var hScore = document.getElementById("lblHighScore");
var mess = document.getElementById("lblMessage");

var ball = {
    x: 0,
    y: 0,
    moveX: 3,
    moveY: -2,
    radius: 12
};
var paddle = {
    x: 0,
    height: 10,
    width: 70,
    moveX: 5,
    moveBy: 0
};
var game = {
    lives: 3,
    playing: false,
    score: 0,
    highScore: 0
};

function initialise(){
    window.addEventListener("resize", resizeCanvas);
    window.addEventListener("mousemove", mouseHasMoved);
    window.addEventListener("keydown", keyPressed);
    window.addEventListener("keyup", keyReleased);
    paddle.x = (window.innerWidth - paddle.width) / 2;
    resizeCanvas();
    setInterval(redraw, 10);
}

function resizeCanvas() {
    canvas.width = window.innerWidth;
    canvas.height = window.innerHeight - parseInt(bar.clientHeight);
    if(ball.x > canvas.width)  {
        ball.x = canvas.width;
    }
    if(ball.y > canvas.height){
        ball.y = canvas.height;
    }
}
function mouseHasMoved(event) {
    let mouseRelX = event.clientX - canvas.offsetLeft;
    if(mouseRelX > 0 && mouseRelX < canvas.width - paddle.width) {
        paddle.x = mouseRelX;
    }
}
function keyPressed(event) {
    if(event.keyCode === 13){
        // Enter key
        if(game.playing == false){
            mess.style.display = "none";
            ball.x = canvas.width / 4;
            ball.y = canvas.height - (ball.radius + paddle.height);
            ball.moveY = -(Math.abs(ball.moveY));
            game.playing = true;
        }
    }
    if(event.keyCode === 37){
        //left arrow
        if(paddle.moveBy === 0) {
            paddle.moveBy = -paddle.moveX;
        }
    }
    if(event.keyCode === 39){
        //right arrow
        if(paddle.moveBy === 0){
            paddle.moveBy = paddle.moveX;
        }
    }
}
function keyReleased(event) {
    if(event.keyCode === 37 || event.keyCode === 39){
        paddle.moveBy = 0;
    }
}
function drawPaddle() {
    ctx.beginPath();
    ctx.rect(paddle.x, canvas.height-paddle.height, paddle.width, paddle.height);
    ctx.fillStyle = "black";
    ctx.fill();
    ctx.closePath();
    if(paddle.moveBy != 0){
        paddle.x += paddle.moveBy;
        if(paddle.x < 0){
            paddle.x = 0;
        }
        if(paddle.x > canvas.width - paddle.width){
            paddle.x = canvas.width - paddle.width;
        }
    }
}
function drawBall() {
    ctx.beginPath();
    ctx.arc(ball.x, ball.y, ball.radius, 0, Math.PI*2);
    ctx.fillStyle = "blue";
    ctx.fill();
    ctx.closePath();
    if((ball.x + ball.moveX + ball.radius) > canvas.width || ball.x + ball.moveX < ball.radius){
        ball.moveX = -ball.moveX;
    }
  
    if(ball.y + ball.moveY < ball.radius) {
        ball.moveY = -ball.moveY;
    }
    
    if(ball.y + ball.moveY + ball.radius > canvas.height - paddle.height){
        if(ball.x >= paddle.x && ball.x <= paddle.x + paddle.width){
            ball.moveY = -ball.moveY;
        } else {
            game.playing = false;
            game.lives--;
            if(game.lives > 0){
                mess.textContent = "Press Enter for next ball";
            } else {
                mess.textContent = "Game Over";
                if(game.score > game.highScore){
                    game.highScore = game.score;
                    hScore.textContent = "High Score: " + game.highScore;
                }
            }
            mess.style.display = "block";
        }
    }
 
    ball.x += ball.moveX;
    ball.y += ball.moveY;
}
function redraw() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    if(game.playing){
        drawBall();
    }
    drawPaddle();
}
initialise();